@@ -20,7 +20,11 @@ from sklearn.inspection import permutation_importance
 from sklearn.metrics import mean_squared_error as mse
 
 # from litelearn import TrainFrame
-from litelearn.expo_ds import default_value, display_evaluation_comparison
+from litelearn.expo_ds import (
+    default_value,
+    display_evaluation_comparison,
+    UNKNOWN_CATEGORY_VALUE,
+)
 from . import residuals
 
 
@@ -444,7 +448,7 @@ class ModelFrame:
                 if dst_dtype.name == "category":
                     unknown_values = set(df[col]) - set(X_train[col].cat.categories)
                     src_col = src_col.replace(
-                        to_replace=unknown_values, value="LITELEARN_UNKNOWN"
+                        to_replace=unknown_values, value=UNKNOWN_CATEGORY_VALUE
                     )
 
                 print("recasting", col, "from", src_dtype, "to", dst_dtype)
@@ -454,9 +458,17 @@ class ModelFrame:
         return df2
 
     def predict(self, df, drop_unused=True):
-        return self.model.predict(self.predict_prepare(df, drop_unused=drop_unused))
+        result = self.model.predict(self.predict_prepare(df, drop_unused=drop_unused))
+        if result.ndim == 1:
+            return pd.Series(result, index=df.index)
+        elif result.ndim == 2 and result.shape[1] == 1:
+            return pd.Series(result[:, 0], index=df.index)
+        else:
+            return pd.DataFrame(result, index=df.index)
 
     def predict_proba(self, df, drop_unused=True):
-        return self.model.predict_proba(
-            self.predict_prepare(df, drop_unused=drop_unused)
+        return pd.DataFrame(
+            self.model.predict_proba(self.predict_prepare(df, drop_unused=drop_unused)),
+            columns=list(self.model.classes_),
+            index=df.index,
         )
